@@ -14,7 +14,7 @@ from django.core.urlresolvers import resolve
 from djexceptional.utils import memoize, json_dumps, meta_to_http
 
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 EXCEPTIONAL_PROTOCOL_VERSION = 5
 EXCEPTIONAL_API_ENDPOINT = "http://api.getexceptional.com/api/errors"
@@ -54,8 +54,6 @@ class ExceptionalMiddleware(object):
         conn = urllib2.urlopen(self.api_endpoint, data=payload)
         try:
             conn.read()
-        except Exception, exc2:
-            import pdb; pdb.set_trace()
         finally:
             conn.close()
 
@@ -160,6 +158,7 @@ class ExceptionalMiddleware(object):
             return settings_file[:-1]
         return settings_file
 
+    @staticmethod
     def filter_params(params):
         """Filter sensitive information out of parameter dictionaries."""
 
